@@ -14,7 +14,7 @@
  *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-/* Some functions that didn't fit */
+/* Some functions that didn't fit elsewhere */
 
 #ifndef DEFINES_H
 # define DEFINES_H
@@ -170,7 +170,7 @@ char buf[6];
   /* headers are ok */
 
   *algorithm=(unsigned int) buf[3];
-  *mode=(unsigned int) buf[4];
+  *mode=(unsigned int) buf[4]; 
   *bit7_flag=(unsigned int) buf[5];
 
 /* 6 To 9 are crc32 */
@@ -209,7 +209,7 @@ unsigned char buf[6];
  buf[1]='m';
  buf[2]='\0';
  buf[3]=(unsigned char) algorithm;
- buf[4]=(unsigned char) mode;
+ buf[4]=(unsigned char) mode; 
  buf[5]=(unsigned char) bit7_flag;
 
 /* 6 to 9 are crc32 */
@@ -289,8 +289,16 @@ char** read_key_file(char * file, int* num) {
   int x=0;
 
   FROMF=fopen(file,"r");
-  if (FROMF==NULL) {perror("fopen");exit(1);}
-  if (read_lock( fileno((FILE*)FROMF))==-1) return 0;
+  if (FROMF==NULL) {
+    fprintf(stderr, _("Keyfile could not be opened. Ignoring it.\n"));
+    return NULL;
+  }
+
+  if (read_lock( fileno((FILE*)FROMF))==-1) {
+    fprintf(stderr, _("Keyfile could not be locked. Ignoring it.\n"));
+    return NULL;
+  }
+
 
   while (fgets( keyword, 128, FROMF)!=NULL) {
     x++;
@@ -301,7 +309,27 @@ char** read_key_file(char * file, int* num) {
     strcpy( keys[x-1], keyword);
 
   }
-*num=x;
-return keys;
+
+  *num=x;
+
+  unlock( fileno((FILE*)FROMF));
+  return keys;
 
 }
+
+#ifdef HAVE_GETPWUID
+char *get_cfile(int uid, char* cfile) {
+
+char *home;
+struct passwd* pwd;
+
+  pwd=getpwuid(uid);
+  home=malloc(strlen(pwd->pw_dir)+strlen(cfile)+2);
+  strcpy(home, pwd->pw_dir);
+  strcat(home, "/");
+  strcat(home, cfile);
+  
+  return home;
+
+}
+#endif
