@@ -52,7 +52,7 @@
 void usage(char *name)
 {
 
-     fprintf(stderr,_("Usage: mcrypt [-dLFus87bhvrx] [-f keyfile] [-k keyword] [-m mode] [-a algorithm] [-c config_file] [file ...]\n\n"));
+     fprintf(stderr,_("Usage: mcrypt [-dLFus87bhvrx] [-f keyfile] [-k keyword] [-m mode] [-i bitmode] [-a algorithm] [-c config_file] [file ...]\n\n"));
 
      fprintf(stderr,_("mini-crypt encrypts/decrypts files using several symmetric block algorithms.\n"));
      fprintf(stderr,_("Legal parameters are:\n\
@@ -162,7 +162,7 @@ int main(int argc,char **argv)
             cfile=malloc(strlen(info.config_file));
             strcpy(cfile,info.config_file);
             if (check_file(cfile)!=1) {
-              err_warn ("Warning: Cannot access config file.\n");
+              err_crit (_("Warning: Cannot access config file.\n"));
             }
           }
           else {
@@ -261,8 +261,8 @@ int main(int argc,char **argv)
                               mode=CBC; /* Default */
 
                               sprintf(tmperr, _("No such mode: %s\n"),modet);
-                              err_warn (tmperr);
-                              err_warn (_("Assuming CBC.\n"));
+                              err_crit (tmperr);
+                              err_crit (_("Assuming CBC.\n"));
 	  	            }
 			  }
                         
@@ -306,11 +306,11 @@ int main(int argc,char **argv)
                                     type=SAFER128;
                                   }
                                   else {
-                                    if (strncasecmp(typet,"CAST128",7)==0) {
+                                    if (strncasecmp(typet,"CAST",4)==0) {
                                     type=CAST128;
                                     }
                                     else {
-                                       if (strncasecmp(typet,"TEAN",4)==0 || strncasecmp(typet,"TEA",3)==0) {
+                                       if (strncasecmp(typet,"TEA",3)==0) {
                                         type=TEAN;
                                        }
                                        else { 
@@ -320,8 +320,8 @@ int main(int argc,char **argv)
                                           else { /* Default */
                                            type=BLOWFISH;
                                            sprintf(tmperr, _("No such algorithm: %s\n"),typet);
-                                           err_warn (tmperr);
-                                           err_warn (_("Assuming Blowfish.\n"));
+                                           err_crit (tmperr);
+                                           err_crit (_("Assuming Blowfish.\n"));
                                           }
                                        }
                                     }
@@ -343,7 +343,7 @@ int main(int argc,char **argv)
 
 /* For RAND32... Called only here */
 #ifndef HAVE_DEV_RANDOM
- if (quiet<=TRUE) err_warn (stderr, "Warning: Using pseudo random numbers\n");
+ if (quiet<=TRUE) err_warn (_("Warning: Using pseudo random numbers\n"));
  srand(time(0)*getpid());
 #endif
 
@@ -386,25 +386,18 @@ for(i=0;i<file_count;i++) {
 #ifdef HAVE_STAT
     if ( is_normal_file( file[i]) == FALSE && stream_flag==FALSE ) {
       sprintf(tmperr, _("%s: %s is not a regular file. Skipping...\n"), argv[0], file[i]);
-      err_warn (tmperr);
+      err_crit (tmperr);
       outfile=NULL;
       continue; /* next */
     }
 #endif
 
-    if (stream_flag==FALSE) {
-      if (quiet==FALSE) fprintf(stderr, _("File: %s\n"),file[i]);
-    }
-    else {
-      if (quiet==FALSE) fprintf(stderr, _("File: stdin\n"));    
-    }
-    
          /* Check how we were called */
 	if (din==TRUE) {
             if (stream_flag!=TRUE) dinfile=file[i];
             if ( (isatty(fileno( (FILE *)(stdin) ) ) == 1) && (stream_flag==TRUE) && (force==0) ) { /* not a tty */        
               sprintf(tmperr, _("%s: Encrypted data will not be read from a terminal.\n"),argv[0]);
-              err_warn (tmperr);
+              err_crit (tmperr);
               err_quit (_("Redirect the input instead.\nUse the --help parameter for more help.\n"));
             }
         } 
@@ -412,7 +405,7 @@ for(i=0;i<file_count;i++) {
             if (stream_flag!=TRUE) einfile=file[i];
             if ( (isatty(fileno( (FILE *)(stdout) ) ) == 1) && (stream_flag==TRUE) && (force==0) ) { /* not a tty */        
               sprintf(tmperr, _("%s: Encrypted data will not be written to a terminal.\n"),argv[0]);
-              err_warn (tmperr);
+              err_crit (tmperr);
               err_quit(_("Redirect the output instead.\nUse the --help parameter for more help.\n"));
             }            
         }
@@ -433,7 +426,7 @@ for(i=0;i<file_count;i++) {
               /* But if it exists exit */
               if (check_file(outfile)!=0) {
                 sprintf(tmperr, _("%s: file %s exists... skipping...\n"), argv[0], outfile);
-                err_warn (tmperr);
+                err_crit (tmperr);
                 continue;
               }
 #endif  	      
@@ -451,7 +444,7 @@ for(i=0;i<file_count;i++) {
             /* if file has already the .enc ignore it */
             if (strstr( outfile, ".enc")!=NULL) {
               sprintf(tmperr, _("%s: file %s has the .enc suffix... skipping...\n"), argv[0], outfile);
-              err_warn (tmperr);
+              err_crit (tmperr);
               continue;
             }
 
@@ -460,7 +453,7 @@ for(i=0;i<file_count;i++) {
               /* But if it exists exit */
               if (check_file(outfile)!=0) {
                 sprintf(tmperr, _("%s: file %s exists... skipping...\n"), argv[0], outfile);
-                err_warn (tmperr);
+                err_crit (tmperr);
                 continue;
               }
 #endif  	      
@@ -486,7 +479,7 @@ for(i=0;i<file_count;i++) {
                else { /* Unix Crypt */
                 if (used_algo==FALSE) {
                  sprintf(tmperr, _("%s: no headers. Assuming encrypted file with Unix crypt.\n"),argv[0]);
-                 err_warn (tmperr);
+                 err_crit (tmperr);
                  fflush(stderr);
                  type=CRYPT;
                 }
@@ -519,7 +512,7 @@ for(i=0;i<file_count;i++) {
                                  x=1;
                                  break;
                                 default:
-	                         err_warn(_("Algorithm unsupported in this version\n"));
+	                         err_crit (_("Algorithm unsupported in this version\n"));
         	                 x=1;
                 	         break;
 	                      }
@@ -528,7 +521,7 @@ for(i=0;i<file_count;i++) {
                           break;
                         default:
                           x=1;
-                          err_warn(_("Mode unsupported in this version\n"));
+                          err_crit (_("Mode unsupported in this version\n"));
                           break;
                       }
                       
@@ -553,11 +546,11 @@ for(i=0;i<file_count;i++) {
 	        	else {
                           if (stream_flag==FALSE) {
                            sprintf(tmperr, _("File %s was NOT decrypted successfully.\n"),dinfile);
-                           err_warn (tmperr);
+                           err_crit (tmperr);
           	           remove(outfile);
         	          }
         	          else {
-        	           err_warn (_("Stdin was NOT decrypted successfully.\n"));
+        	           err_crit (_("Stdin was NOT decrypted successfully.\n"));
         	          }
         	        }
         
@@ -590,7 +583,7 @@ for(i=0;i<file_count;i++) {
 	        	 break;
 	        	 
 	        	default:
-                         err_warn(_("Algorithm unsupported in this version\n"));
+                         err_crit (_("Algorithm unsupported in this version\n"));
 	        	 x=1;
 	        	 break;
                         }
@@ -598,7 +591,7 @@ for(i=0;i<file_count;i++) {
 
                    default:
                     x=1;
-                    err_warn (_("Mode unsupported in this version\n"));
+                    err_crit (_("Mode unsupported in this version\n"));
                     break;
                   }
 
@@ -621,11 +614,11 @@ for(i=0;i<file_count;i++) {
 	                else {
                          if (stream_flag==FALSE) {
                           sprintf(tmperr, _("File %s was NOT encrypted successfully.\n"),einfile);
-                          err_warn (tmperr);
+                          err_crit (tmperr);
                           remove(outfile);
 	                 }
                          else {
-	                  err_warn (_("Stdin was NOT encrypted successfully.\n"));
+	                  err_crit (_("Stdin was NOT encrypted successfully.\n"));
 	                 }
 
 	                }
@@ -681,7 +674,7 @@ else {
          Bzero(keyword,sizeof(keyword));
 
 	if (key==NULL) 	{
-          if (quiet==TRUE && stream_flag==FALSE) fprintf(stderr, _("File: %s\n"),fromfile);
+          if (quiet<=1 && stream_flag==FALSE) fprintf(stderr, _("File: %s\n"),fromfile);
           tmp=get_password(8, bit7_flag, DECRYPT, type, &len);
           if (tmp==NULL) return 1;
           memmove(keyword, tmp, len);
@@ -691,7 +684,7 @@ else {
 	else {
            if (strlen(key) > 8) {
              key[8]='\0'; 
-             err_warn(_("Warning: Reducing the size of the key\n"));
+             err_warn (_("Warning: Reducing the size of the key\n"));
            }
 	   memmove(keyword, key, strlen(key)); /* Copy the 64 bits in key */
 	}
@@ -701,7 +694,7 @@ if (quiet==FALSE) show_mode(ENCRYPT,type,mode,tofile,bit7_flag);
 
 
   if (unix_setup(keyword)==1) {
-    err_warn(_("Cannot encrypt key\n"));
+    err_crit (_("Cannot encrypt key\n"));
     return 1; 
   }/* init the crypt */
 
@@ -821,7 +814,7 @@ if (mode==CBC || mode==CFB) {
   }  
 
   if (key==NULL) {
-    if (quiet==TRUE && stream_flag==FALSE) fprintf(stderr, _("File: %s\n"),fromfile);
+    if (quiet<=TRUE && stream_flag==FALSE) fprintf(stderr, _("File: %s\n"),fromfile);
   }
 
 
@@ -854,7 +847,7 @@ if (mode==CBC || mode==CFB) {
   }  
 
    if (td<0) { 
-     err_warn (_("Unknown algorithm error\n"));
+     err_crit (_("Unknown algorithm error\n"));
      return 1;
    }
 
@@ -1109,7 +1102,7 @@ else {
 
 /* Get key */
   if (key==NULL) {
-    if (quiet==TRUE && stream_flag==FALSE) fprintf(stderr, _("File: %s\n"),fromfile);
+    if (quiet<=TRUE && stream_flag==FALSE) fprintf(stderr, _("File: %s\n"),fromfile);
   }
 
   if (key==NULL) {
@@ -1178,9 +1171,9 @@ switch (mode) {
              }
              else { /* eof */
                ch=1;
-               if (i==0) { err_warn(_("Incorrect file type\n")); return 1;}
+               if (i==0) { err_crit (_("Incorrect file type\n")); return 1;}
                memmove(&counter, ciphertext, sizeof(counter));
-               if (counter >= blocksize) { err_warn(_("Incorrect file type\n")); return 1;}
+               if (counter >= blocksize) { err_crit (_("Incorrect file type\n")); return 1;}
              }
            }
 
@@ -1237,9 +1230,9 @@ switch (mode) {
              }
              else { /* eof */
                ch=1;
-               if (i==0) {err_warn(_("Incorrect file type\n")); return 1;}
+               if (i==0) {err_crit (_("Incorrect file type\n")); return 1;}
                memmove(&counter, ciphertext, sizeof(counter));
-               if (counter >= blocksize) {err_warn(_("Incorrect file type\n")); return 1;}
+               if (counter >= blocksize) {err_crit (_("Incorrect file type\n")); return 1;}
              }
            }
 
@@ -1365,7 +1358,7 @@ switch (mode) {
      return 0; /* crc check passed */
     }
     else {
-     err_warn(_("CRC32 check failed\n"));
+     err_crit (_("CRC32 check failed\n"));
      return 1; /* CRC32s Do not match */
     }
  }
